@@ -20,7 +20,8 @@ _linearizations = {'akirich': 3, 'fatti': 3, 'ps': 3}
 
 
 def PrestackLinearModelling(wav, theta, vsvp=0.5, nt0=1, spatdims=None,
-                            linearization='akirich', explicit=False):
+                            linearization='akirich', explicit=False,
+                            kind='centered'):
     r"""Pre-stack linearized seismic modelling operator.
 
     Create operator to be applied to elastic property profiles
@@ -57,6 +58,8 @@ def PrestackLinearModelling(wav, theta, vsvp=0.5, nt0=1, spatdims=None,
         Create a chained linear operator (``False``, preferred for large data)
         or a ``MatrixMult`` linear operator with dense matrix
         (``True``, preferred for small data)
+    kind : :obj:`str`, optional
+        Derivative kind (``forward`` or ``centered``).
 
     Returns
     -------
@@ -67,6 +70,8 @@ def PrestackLinearModelling(wav, theta, vsvp=0.5, nt0=1, spatdims=None,
     ------
     NotImplementedError
         If ``linearization`` is not an implemented linearization
+    NotImplementedError
+        If ``kind`` is not ``forward`` nor ``centered``
 
     Notes
     -----
@@ -90,6 +95,10 @@ def PrestackLinearModelling(wav, theta, vsvp=0.5, nt0=1, spatdims=None,
     """
     ncp = get_array_module(wav)
 
+    # check kind is correctly selected
+    if kind not in ['forward', 'centered']:
+        raise NotImplementedError('%s not an available derivative kind...'
+                                  % kind)
     # define dtype to be used
     dtype = theta.dtype # ensure theta.dtype rules that of operator
     theta = theta.astype(dtype)
@@ -131,9 +140,14 @@ def PrestackLinearModelling(wav, theta, vsvp=0.5, nt0=1, spatdims=None,
         G = ncp.vstack(G).reshape(ntheta * nt0, nG * nt0)
 
         # Create derivative operator
-        D = ncp.diag(0.5 * ncp.ones(nt0 - 1, dtype=dtype), k=1) - \
-            ncp.diag(0.5 * ncp.ones(nt0 - 1, dtype=dtype), k=-1)
-        D[0] = D[-1] = 0
+        if kind == 'centered':
+            D = ncp.diag(0.5 * ncp.ones(nt0 - 1, dtype=dtype), k=1) - \
+                ncp.diag(0.5 * ncp.ones(nt0 - 1, dtype=dtype), k=-1)
+            D[0] = D[-1] = 0
+        else:
+            D = ncp.diag(ncp.ones(nt0 - 1, dtype=dtype), k=1) - \
+                ncp.diag(ncp.ones(nt0, dtype=dtype), k=0)
+            D[-1] = 0
         D = get_block_diag(theta)(*([D] * nG))
 
         # Create wavelet operator
@@ -158,7 +172,7 @@ def PrestackLinearModelling(wav, theta, vsvp=0.5, nt0=1, spatdims=None,
         dimsm = list(dims)
         dimsm[1] = AVOop.npars
         Dop = FirstDerivative(np.prod(np.array(dimsm)), dims=dimsm,
-                              dir=0, sampling=1., dtype=dtype)
+                              dir=0, sampling=1., kind=kind, dtype=dtype)
         Preop = Cop * AVOop * Dop
     return Preop
 
@@ -270,7 +284,8 @@ def PrestackWaveletModelling(m, theta, nwav, wavc=None,
 def PrestackInversion(data, theta, wav, m0=None, linearization='akirich',
                       explicit=False, simultaneous=False,
                       epsI=None, epsR=None, dottest=False,
-                      returnres=False, epsRL1=None, **kwargs_solver):
+                      returnres=False, epsRL1=None, kind='centered',
+                      vsvp=0.5, **kwargs_solver):
     r"""Pre-stack linearized seismic inversion.
 
     Invert pre-stack seismic operator to retrieve a set of elastic property
@@ -317,6 +332,10 @@ def PrestackInversion(data, theta, wav, m0=None, linearization='akirich',
         Return residuals
     epsRL1 : :obj:`float`, optional
         Damping factor for additional blockiness regularization term
+    kind : :obj:`str`, optional
+        Derivative kind (``forward`` or ``centered``).
+    vsvp : :obj:`float` or :obj:`np.ndarray`
+        VS/VP ratio (constant or time/depth variant)
     **kwargs_solver
         Arbitrary keyword arguments for :py:func:`scipy.linalg.lstsq`
         solver (if ``explicit=True`` and  ``epsR=None``)
@@ -392,15 +411,16 @@ def PrestackInversion(data, theta, wav, m0=None, linearization='akirich',
     # create operator
     if isinstance(linearization, str):
         # single operator
-        PPop = PrestackLinearModelling(wav, theta, nt0=nt0, spatdims=nspat,
+        PPop = PrestackLinearModelling(wav, theta, vsvp=vsvp, nt0=nt0, spatdims=nspat,
                                        linearization=linearization,
-                                       explicit=explicit)
+                                       explicit=explicit, kind=kind)
     else:
         # multiple operators
         if not isinstance(wav, (list, tuple)):
             wav = [wav,] * n_lins
-        PPop = [PrestackLinearModelling(w, theta, nt0=nt0, spatdims=nspat,
-                                       linearization=lin, explicit=explicit)
+        PPop = [PrestackLinearModelling(w, theta, vsvp=vsvp, nt0=nt0,
+                                        spatdims=nspat, linearization=lin,
+                                        explicit=explicit)
                 for w, lin in zip(wav, linearization)]
         if explicit:
             PPop = MatrixMult(np.vstack([Op.A for Op in PPop]), dims=nspat,
