@@ -8,9 +8,14 @@ from .Interp import Interp
 from .Bilinear import Bilinear
 from .Radon2D import Radon2D
 from .Radon3D import Radon3D
+from .Sliding1D import Sliding1D
 from .Sliding2D import Sliding2D
 from .Sliding3D import Sliding3D
+from .Patch2D import Patch2D
 from .Fredholm1 import Fredholm1
 from .DWT import DWT
 from .DWT2D import DWT2D
 from .Seislet import Seislet
+from .ChirpRadon2D import ChirpRadon2D
+from .ChirpRadon3D import ChirpRadon3D
+from .Shift import Shift
\ No newline at end of file
